# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_conditions/v1/tick_conditions.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/tick_conditions/v1/tick_conditions.proto',
  package='systemathics.apis.services.tick_conditions.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nCsystemathics/apis/services/tick_conditions/v1/tick_conditions.proto\x12-systemathics.apis.services.tick_conditions.v1\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\x8a\x01\n\x15TickConditionsRequest\x12\x42\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierH\x00\x12\x12\n\x08\x65xchange\x18\x02 \x01(\tH\x00\x12\x10\n\x06source\x18\x03 \x01(\x05H\x00\x42\x07\n\x05value\"`\n\x16TickConditionsResponse\x12\x46\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x38.systemathics.apis.services.tick_conditions.v1.Condition\"b\n\tCondition\x12\r\n\x05value\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07\x63omment\x18\x03 \x01(\t\x12\x0f\n\x07regular\x18\x04 \x01(\x08\x12\x0f\n\x07\x61uction\x18\x05 \x01(\x08\x32\xb7\x01\n\x15TickConditionsService\x12\x9d\x01\n\x0eTickConditions\x12\x44.systemathics.apis.services.tick_conditions.v1.TickConditionsRequest\x1a\x45.systemathics.apis.services.tick_conditions.v1.TickConditionsResponseb\x06proto3'
  ,
  dependencies=[systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,])




_TICKCONDITIONSREQUEST = _descriptor.Descriptor(
  name='TickConditionsRequest',
  full_name='systemathics.apis.services.tick_conditions.v1.TickConditionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.tick_conditions.v1.TickConditionsRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='systemathics.apis.services.tick_conditions.v1.TickConditionsRequest.exchange', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='systemathics.apis.services.tick_conditions.v1.TickConditionsRequest.source', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='systemathics.apis.services.tick_conditions.v1.TickConditionsRequest.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=170,
  serialized_end=308,
)


_TICKCONDITIONSRESPONSE = _descriptor.Descriptor(
  name='TickConditionsResponse',
  full_name='systemathics.apis.services.tick_conditions.v1.TickConditionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='systemathics.apis.services.tick_conditions.v1.TickConditionsResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=310,
  serialized_end=406,
)


_CONDITION = _descriptor.Descriptor(
  name='Condition',
  full_name='systemathics.apis.services.tick_conditions.v1.Condition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.tick_conditions.v1.Condition.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='systemathics.apis.services.tick_conditions.v1.Condition.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='comment', full_name='systemathics.apis.services.tick_conditions.v1.Condition.comment', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regular', full_name='systemathics.apis.services.tick_conditions.v1.Condition.regular', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auction', full_name='systemathics.apis.services.tick_conditions.v1.Condition.auction', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=408,
  serialized_end=506,
)

_TICKCONDITIONSREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_TICKCONDITIONSREQUEST.oneofs_by_name['value'].fields.append(
  _TICKCONDITIONSREQUEST.fields_by_name['identifier'])
_TICKCONDITIONSREQUEST.fields_by_name['identifier'].containing_oneof = _TICKCONDITIONSREQUEST.oneofs_by_name['value']
_TICKCONDITIONSREQUEST.oneofs_by_name['value'].fields.append(
  _TICKCONDITIONSREQUEST.fields_by_name['exchange'])
_TICKCONDITIONSREQUEST.fields_by_name['exchange'].containing_oneof = _TICKCONDITIONSREQUEST.oneofs_by_name['value']
_TICKCONDITIONSREQUEST.oneofs_by_name['value'].fields.append(
  _TICKCONDITIONSREQUEST.fields_by_name['source'])
_TICKCONDITIONSREQUEST.fields_by_name['source'].containing_oneof = _TICKCONDITIONSREQUEST.oneofs_by_name['value']
_TICKCONDITIONSRESPONSE.fields_by_name['data'].message_type = _CONDITION
DESCRIPTOR.message_types_by_name['TickConditionsRequest'] = _TICKCONDITIONSREQUEST
DESCRIPTOR.message_types_by_name['TickConditionsResponse'] = _TICKCONDITIONSRESPONSE
DESCRIPTOR.message_types_by_name['Condition'] = _CONDITION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TickConditionsRequest = _reflection.GeneratedProtocolMessageType('TickConditionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKCONDITIONSREQUEST,
  '__module__' : 'systemathics.apis.services.tick_conditions.v1.tick_conditions_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_conditions.v1.TickConditionsRequest)
  })
_sym_db.RegisterMessage(TickConditionsRequest)

TickConditionsResponse = _reflection.GeneratedProtocolMessageType('TickConditionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKCONDITIONSRESPONSE,
  '__module__' : 'systemathics.apis.services.tick_conditions.v1.tick_conditions_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_conditions.v1.TickConditionsResponse)
  })
_sym_db.RegisterMessage(TickConditionsResponse)

Condition = _reflection.GeneratedProtocolMessageType('Condition', (_message.Message,), {
  'DESCRIPTOR' : _CONDITION,
  '__module__' : 'systemathics.apis.services.tick_conditions.v1.tick_conditions_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_conditions.v1.Condition)
  })
_sym_db.RegisterMessage(Condition)



_TICKCONDITIONSSERVICE = _descriptor.ServiceDescriptor(
  name='TickConditionsService',
  full_name='systemathics.apis.services.tick_conditions.v1.TickConditionsService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=509,
  serialized_end=692,
  methods=[
  _descriptor.MethodDescriptor(
    name='TickConditions',
    full_name='systemathics.apis.services.tick_conditions.v1.TickConditionsService.TickConditions',
    index=0,
    containing_service=None,
    input_type=_TICKCONDITIONSREQUEST,
    output_type=_TICKCONDITIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TICKCONDITIONSSERVICE)

DESCRIPTOR.services_by_name['TickConditionsService'] = _TICKCONDITIONSSERVICE

# @@protoc_insertion_point(module_scope)
