# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily/v1/daily_prices.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/daily/v1/daily_prices.proto',
  package='systemathics.apis.services.daily.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n6systemathics/apis/services/daily/v1/daily_prices.proto\x12#systemathics.apis.services.daily.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\xae\x01\n\x12\x44\x61ilyPricesRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x03 \x01(\x08\"T\n\x13\x44\x61ilyPricesResponse\x12=\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32/.systemathics.apis.services.daily.v1.DailyPrice\"[\n\nDailyPrice\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\r\n\x05price\x18\x02 \x01(\x01\x12\x0e\n\x06volume\x18\x03 \x01(\x03\x12\r\n\x05score\x18\x04 \x01(\x01\x32\x97\x01\n\x12\x44\x61ilyPricesService\x12\x80\x01\n\x0b\x44\x61ilyPrices\x12\x37.systemathics.apis.services.daily.v1.DailyPricesRequest\x1a\x38.systemathics.apis.services.daily.v1.DailyPricesResponseb\x06proto3'
  ,
  dependencies=[google_dot_type_dot_date__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,])




_DAILYPRICESREQUEST = _descriptor.Descriptor(
  name='DailyPricesRequest',
  full_name='systemathics.apis.services.daily.v1.DailyPricesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.daily.v1.DailyPricesRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.daily.v1.DailyPricesRequest.constraints', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adjustment', full_name='systemathics.apis.services.daily.v1.DailyPricesRequest.adjustment', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=223,
  serialized_end=397,
)


_DAILYPRICESRESPONSE = _descriptor.Descriptor(
  name='DailyPricesResponse',
  full_name='systemathics.apis.services.daily.v1.DailyPricesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='systemathics.apis.services.daily.v1.DailyPricesResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=399,
  serialized_end=483,
)


_DAILYPRICE = _descriptor.Descriptor(
  name='DailyPrice',
  full_name='systemathics.apis.services.daily.v1.DailyPrice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='systemathics.apis.services.daily.v1.DailyPrice.date', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='systemathics.apis.services.daily.v1.DailyPrice.price', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='systemathics.apis.services.daily.v1.DailyPrice.volume', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='systemathics.apis.services.daily.v1.DailyPrice.score', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=485,
  serialized_end=576,
)

_DAILYPRICESREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_DAILYPRICESREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_DAILYPRICESRESPONSE.fields_by_name['data'].message_type = _DAILYPRICE
_DAILYPRICE.fields_by_name['date'].message_type = google_dot_type_dot_date__pb2._DATE
DESCRIPTOR.message_types_by_name['DailyPricesRequest'] = _DAILYPRICESREQUEST
DESCRIPTOR.message_types_by_name['DailyPricesResponse'] = _DAILYPRICESRESPONSE
DESCRIPTOR.message_types_by_name['DailyPrice'] = _DAILYPRICE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DailyPricesRequest = _reflection.GeneratedProtocolMessageType('DailyPricesRequest', (_message.Message,), {
  'DESCRIPTOR' : _DAILYPRICESREQUEST,
  '__module__' : 'systemathics.apis.services.daily.v1.daily_prices_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily.v1.DailyPricesRequest)
  })
_sym_db.RegisterMessage(DailyPricesRequest)

DailyPricesResponse = _reflection.GeneratedProtocolMessageType('DailyPricesResponse', (_message.Message,), {
  'DESCRIPTOR' : _DAILYPRICESRESPONSE,
  '__module__' : 'systemathics.apis.services.daily.v1.daily_prices_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily.v1.DailyPricesResponse)
  })
_sym_db.RegisterMessage(DailyPricesResponse)

DailyPrice = _reflection.GeneratedProtocolMessageType('DailyPrice', (_message.Message,), {
  'DESCRIPTOR' : _DAILYPRICE,
  '__module__' : 'systemathics.apis.services.daily.v1.daily_prices_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily.v1.DailyPrice)
  })
_sym_db.RegisterMessage(DailyPrice)



_DAILYPRICESSERVICE = _descriptor.ServiceDescriptor(
  name='DailyPricesService',
  full_name='systemathics.apis.services.daily.v1.DailyPricesService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=579,
  serialized_end=730,
  methods=[
  _descriptor.MethodDescriptor(
    name='DailyPrices',
    full_name='systemathics.apis.services.daily.v1.DailyPricesService.DailyPrices',
    index=0,
    containing_service=None,
    input_type=_DAILYPRICESREQUEST,
    output_type=_DAILYPRICESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DAILYPRICESSERVICE)

DESCRIPTOR.services_by_name['DailyPricesService'] = _DAILYPRICESSERVICE

# @@protoc_insertion_point(module_scope)
