# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick/v1/tick_trades_and_book.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import mappings_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_mappings__pb2
from systemathics.apis.type.shared.v1 import level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2
from systemathics.apis.type.shared.v1 import market_book_updates_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_market__book__updates__pb2
from systemathics.apis.type.shared.v1 import market_fields_updates_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_market__fields__updates__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import keys_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_keys__pb2
from systemathics.apis.type.shared.v1 import book_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_book__pb2
from systemathics.apis.type.shared.v1 import trade_and_book_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_trade__and__book__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/tick/v1/tick_trades_and_book.proto',
  package='systemathics.apis.services.tick.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=systemathics/apis/services/tick/v1/tick_trades_and_book.proto\x12\"systemathics.apis.services.tick.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a/systemathics/apis/type/shared/v1/mappings.proto\x1a,systemathics/apis/type/shared/v1/level.proto\x1a:systemathics/apis/type/shared/v1/market_book_updates.proto\x1a<systemathics/apis/type/shared/v1/market_fields_updates.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a+systemathics/apis/type/shared/v1/keys.proto\x1a+systemathics/apis/type/shared/v1/book.proto\x1a\x35systemathics/apis/type/shared/v1/trade_and_book.proto\"\xa1\x01\n\x18TickTradesAndBookRequest\x12\x41\n\x0bidentifiers\x18\x01 \x03(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\"\xa1\x01\n\x19TickTradesAndBookResponse\x12>\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32..systemathics.apis.type.shared.v1.TradeAndBookH\x00\x12\x39\n\x07mapping\x18\x02 \x01(\x0b\x32&.systemathics.apis.type.shared.v1.KeysH\x00\x42\t\n\x07payload2\xaf\x01\n\x18TickTradesAndBookService\x12\x92\x01\n\x11TickTradesAndBook\x12<.systemathics.apis.services.tick.v1.TickTradesAndBookRequest\x1a=.systemathics.apis.services.tick.v1.TickTradesAndBookResponse0\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_mappings__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_market__book__updates__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_market__fields__updates__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_keys__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_book__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_trade__and__book__pb2.DESCRIPTOR,])




_TICKTRADESANDBOOKREQUEST = _descriptor.Descriptor(
  name='TickTradesAndBookRequest',
  full_name='systemathics.apis.services.tick.v1.TickTradesAndBookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifiers', full_name='systemathics.apis.services.tick.v1.TickTradesAndBookRequest.identifiers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.tick.v1.TickTradesAndBookRequest.constraints', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=600,
  serialized_end=761,
)


_TICKTRADESANDBOOKRESPONSE = _descriptor.Descriptor(
  name='TickTradesAndBookResponse',
  full_name='systemathics.apis.services.tick.v1.TickTradesAndBookResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='systemathics.apis.services.tick.v1.TickTradesAndBookResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mapping', full_name='systemathics.apis.services.tick.v1.TickTradesAndBookResponse.mapping', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='systemathics.apis.services.tick.v1.TickTradesAndBookResponse.payload',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=764,
  serialized_end=925,
)

_TICKTRADESANDBOOKREQUEST.fields_by_name['identifiers'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_TICKTRADESANDBOOKREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_TICKTRADESANDBOOKRESPONSE.fields_by_name['data'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_trade__and__book__pb2._TRADEANDBOOK
_TICKTRADESANDBOOKRESPONSE.fields_by_name['mapping'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_keys__pb2._KEYS
_TICKTRADESANDBOOKRESPONSE.oneofs_by_name['payload'].fields.append(
  _TICKTRADESANDBOOKRESPONSE.fields_by_name['data'])
_TICKTRADESANDBOOKRESPONSE.fields_by_name['data'].containing_oneof = _TICKTRADESANDBOOKRESPONSE.oneofs_by_name['payload']
_TICKTRADESANDBOOKRESPONSE.oneofs_by_name['payload'].fields.append(
  _TICKTRADESANDBOOKRESPONSE.fields_by_name['mapping'])
_TICKTRADESANDBOOKRESPONSE.fields_by_name['mapping'].containing_oneof = _TICKTRADESANDBOOKRESPONSE.oneofs_by_name['payload']
DESCRIPTOR.message_types_by_name['TickTradesAndBookRequest'] = _TICKTRADESANDBOOKREQUEST
DESCRIPTOR.message_types_by_name['TickTradesAndBookResponse'] = _TICKTRADESANDBOOKRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TickTradesAndBookRequest = _reflection.GeneratedProtocolMessageType('TickTradesAndBookRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKTRADESANDBOOKREQUEST,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_trades_and_book_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickTradesAndBookRequest)
  })
_sym_db.RegisterMessage(TickTradesAndBookRequest)

TickTradesAndBookResponse = _reflection.GeneratedProtocolMessageType('TickTradesAndBookResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKTRADESANDBOOKRESPONSE,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_trades_and_book_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickTradesAndBookResponse)
  })
_sym_db.RegisterMessage(TickTradesAndBookResponse)



_TICKTRADESANDBOOKSERVICE = _descriptor.ServiceDescriptor(
  name='TickTradesAndBookService',
  full_name='systemathics.apis.services.tick.v1.TickTradesAndBookService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=928,
  serialized_end=1103,
  methods=[
  _descriptor.MethodDescriptor(
    name='TickTradesAndBook',
    full_name='systemathics.apis.services.tick.v1.TickTradesAndBookService.TickTradesAndBook',
    index=0,
    containing_service=None,
    input_type=_TICKTRADESANDBOOKREQUEST,
    output_type=_TICKTRADESANDBOOKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TICKTRADESANDBOOKSERVICE)

DESCRIPTOR.services_by_name['TickTradesAndBookService'] = _TICKTRADESANDBOOKSERVICE

# @@protoc_insertion_point(module_scope)
