# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/market_fields_updates.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import action_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_action__pb2
from systemathics.apis.type.shared.v1 import field_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_field__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/type/shared/v1/market_fields_updates.proto',
  package='systemathics.apis.type.shared.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n<systemathics/apis/type/shared/v1/market_fields_updates.proto\x12 systemathics.apis.type.shared.v1\x1a-systemathics/apis/type/shared/v1/action.proto\x1a,systemathics/apis/type/shared/v1/field.proto\"p\n\x13MarketFieldsUpdates\x12\x13\n\x0bis_snapshot\x18\x01 \x01(\x08\x12\x44\n\x07updates\x18\x02 \x03(\x0b\x32\x33.systemathics.apis.type.shared.v1.MarketFieldUpdate\"\xd4\x01\n\x11MarketFieldUpdate\x12\x38\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32(.systemathics.apis.type.shared.v1.Action\x12\x36\n\x05\x66ield\x18\x02 \x01(\x0e\x32\'.systemathics.apis.type.shared.v1.Field\x12\x14\n\nlong_value\x18\x03 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x04 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x05 \x01(\tH\x00\x42\x07\n\x05valueb\x06proto3'
  ,
  dependencies=[systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_action__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_field__pb2.DESCRIPTOR,])




_MARKETFIELDSUPDATES = _descriptor.Descriptor(
  name='MarketFieldsUpdates',
  full_name='systemathics.apis.type.shared.v1.MarketFieldsUpdates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_snapshot', full_name='systemathics.apis.type.shared.v1.MarketFieldsUpdates.is_snapshot', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updates', full_name='systemathics.apis.type.shared.v1.MarketFieldsUpdates.updates', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=191,
  serialized_end=303,
)


_MARKETFIELDUPDATE = _descriptor.Descriptor(
  name='MarketFieldUpdate',
  full_name='systemathics.apis.type.shared.v1.MarketFieldUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='systemathics.apis.type.shared.v1.MarketFieldUpdate.action', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field', full_name='systemathics.apis.type.shared.v1.MarketFieldUpdate.field', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='long_value', full_name='systemathics.apis.type.shared.v1.MarketFieldUpdate.long_value', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='double_value', full_name='systemathics.apis.type.shared.v1.MarketFieldUpdate.double_value', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='systemathics.apis.type.shared.v1.MarketFieldUpdate.string_value', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='systemathics.apis.type.shared.v1.MarketFieldUpdate.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=306,
  serialized_end=518,
)

_MARKETFIELDSUPDATES.fields_by_name['updates'].message_type = _MARKETFIELDUPDATE
_MARKETFIELDUPDATE.fields_by_name['action'].enum_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_action__pb2._ACTION
_MARKETFIELDUPDATE.fields_by_name['field'].enum_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_field__pb2._FIELD
_MARKETFIELDUPDATE.oneofs_by_name['value'].fields.append(
  _MARKETFIELDUPDATE.fields_by_name['long_value'])
_MARKETFIELDUPDATE.fields_by_name['long_value'].containing_oneof = _MARKETFIELDUPDATE.oneofs_by_name['value']
_MARKETFIELDUPDATE.oneofs_by_name['value'].fields.append(
  _MARKETFIELDUPDATE.fields_by_name['double_value'])
_MARKETFIELDUPDATE.fields_by_name['double_value'].containing_oneof = _MARKETFIELDUPDATE.oneofs_by_name['value']
_MARKETFIELDUPDATE.oneofs_by_name['value'].fields.append(
  _MARKETFIELDUPDATE.fields_by_name['string_value'])
_MARKETFIELDUPDATE.fields_by_name['string_value'].containing_oneof = _MARKETFIELDUPDATE.oneofs_by_name['value']
DESCRIPTOR.message_types_by_name['MarketFieldsUpdates'] = _MARKETFIELDSUPDATES
DESCRIPTOR.message_types_by_name['MarketFieldUpdate'] = _MARKETFIELDUPDATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MarketFieldsUpdates = _reflection.GeneratedProtocolMessageType('MarketFieldsUpdates', (_message.Message,), {
  'DESCRIPTOR' : _MARKETFIELDSUPDATES,
  '__module__' : 'systemathics.apis.type.shared.v1.market_fields_updates_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.MarketFieldsUpdates)
  })
_sym_db.RegisterMessage(MarketFieldsUpdates)

MarketFieldUpdate = _reflection.GeneratedProtocolMessageType('MarketFieldUpdate', (_message.Message,), {
  'DESCRIPTOR' : _MARKETFIELDUPDATE,
  '__module__' : 'systemathics.apis.type.shared.v1.market_fields_updates_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.MarketFieldUpdate)
  })
_sym_db.RegisterMessage(MarketFieldUpdate)


# @@protoc_insertion_point(module_scope)
