# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/memo.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/type/shared/v1/memo.proto',
  package='systemathics.apis.type.shared.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+systemathics/apis/type/shared/v1/memo.proto\x12 systemathics.apis.type.shared.v1\"G\n\x04Memo\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\r\n\x05group\x18\x02 \x01(\t\x12\x0e\n\x06stream\x18\x03 \x01(\t\x12\x0e\n\x06ticker\x18\x04 \x01(\tb\x06proto3'
)




_MEMO = _descriptor.Descriptor(
  name='Memo',
  full_name='systemathics.apis.type.shared.v1.Memo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='provider', full_name='systemathics.apis.type.shared.v1.Memo.provider', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group', full_name='systemathics.apis.type.shared.v1.Memo.group', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream', full_name='systemathics.apis.type.shared.v1.Memo.stream', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticker', full_name='systemathics.apis.type.shared.v1.Memo.ticker', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=152,
)

DESCRIPTOR.message_types_by_name['Memo'] = _MEMO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Memo = _reflection.GeneratedProtocolMessageType('Memo', (_message.Message,), {
  'DESCRIPTOR' : _MEMO,
  '__module__' : 'systemathics.apis.type.shared.v1.memo_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Memo)
  })
_sym_db.RegisterMessage(Memo)


# @@protoc_insertion_point(module_scope)
