# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/field.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/type/shared/v1/field.proto',
  package='systemathics.apis.type.shared.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,systemathics/apis/type/shared/v1/field.proto\x12 systemathics.apis.type.shared.v1*\xdd\x04\n\x05\x46ield\x12\x15\n\x11\x46IELD_UNSPECIFIED\x10\x00\x12\x14\n\x10\x46IELD_OPEN_PRICE\x10\x01\x12\x13\n\x0f\x46IELD_OPEN_SIZE\x10\x02\x12\x15\n\x11\x46IELD_CLOSE_PRICE\x10\x03\x12\x14\n\x10\x46IELD_CLOSE_SIZE\x10\x04\x12\x13\n\x0f\x46IELD_LOW_PRICE\x10\x05\x12\x12\n\x0e\x46IELD_LOW_SIZE\x10\x06\x12\x14\n\x10\x46IELD_HIGH_PRICE\x10\x07\x12\x13\n\x0f\x46IELD_HIGH_SIZE\x10\x08\x12\x15\n\x11\x46IELD_TRADE_PRICE\x10\t\x12\x14\n\x10\x46IELD_TRADE_SIZE\x10\n\x12\x1b\n\x17\x46IELD_TRADING_CONDITION\x10\x0b\x12\x15\n\x11\x46IELD_TRADE_COUNT\x10\x0c\x12\x19\n\x15\x46IELD_TRADE_OTC_PRICE\x10\r\x12\x18\n\x14\x46IELD_TRADE_OTC_SIZE\x10\x0e\x12\x19\n\x15\x46IELD_TRADE_OTC_COUNT\x10\x0f\x12\x10\n\x0c\x46IELD_VOLUME\x10\x10\x12\x17\n\x13\x46IELD_VWAP_OFFICIAL\x10\x11\x12\x19\n\x15\x46IELD_VWAP_ELECTRONIC\x10\x12\x12\x1b\n\x17\x46IELD_THEORETICAL_PRICE\x10\x13\x12\x1a\n\x16\x46IELD_THEORETICAL_SIZE\x10\x14\x12\x15\n\x11\x46IELD_UPPER_PRICE\x10\x15\x12\x15\n\x11\x46IELD_LOWER_PRICE\x10\x16\x12\x13\n\x0f\x46IELD_VARIATION\x10\x17\x12\x1e\n\x1a\x46IELD_VARIATION_PERCENTAGE\x10\x18\x62\x06proto3'
)

_FIELD = _descriptor.EnumDescriptor(
  name='Field',
  full_name='systemathics.apis.type.shared.v1.Field',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FIELD_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_OPEN_PRICE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_OPEN_SIZE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_CLOSE_PRICE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_CLOSE_SIZE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_LOW_PRICE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_LOW_SIZE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_HIGH_PRICE', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_HIGH_SIZE', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_TRADE_PRICE', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_TRADE_SIZE', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_TRADING_CONDITION', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_TRADE_COUNT', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_TRADE_OTC_PRICE', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_TRADE_OTC_SIZE', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_TRADE_OTC_COUNT', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_VOLUME', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_VWAP_OFFICIAL', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_VWAP_ELECTRONIC', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_THEORETICAL_PRICE', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_THEORETICAL_SIZE', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_UPPER_PRICE', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_LOWER_PRICE', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_VARIATION', index=23, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_VARIATION_PERCENTAGE', index=24, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=83,
  serialized_end=688,
)
_sym_db.RegisterEnumDescriptor(_FIELD)

Field = enum_type_wrapper.EnumTypeWrapper(_FIELD)
FIELD_UNSPECIFIED = 0
FIELD_OPEN_PRICE = 1
FIELD_OPEN_SIZE = 2
FIELD_CLOSE_PRICE = 3
FIELD_CLOSE_SIZE = 4
FIELD_LOW_PRICE = 5
FIELD_LOW_SIZE = 6
FIELD_HIGH_PRICE = 7
FIELD_HIGH_SIZE = 8
FIELD_TRADE_PRICE = 9
FIELD_TRADE_SIZE = 10
FIELD_TRADING_CONDITION = 11
FIELD_TRADE_COUNT = 12
FIELD_TRADE_OTC_PRICE = 13
FIELD_TRADE_OTC_SIZE = 14
FIELD_TRADE_OTC_COUNT = 15
FIELD_VOLUME = 16
FIELD_VWAP_OFFICIAL = 17
FIELD_VWAP_ELECTRONIC = 18
FIELD_THEORETICAL_PRICE = 19
FIELD_THEORETICAL_SIZE = 20
FIELD_UPPER_PRICE = 21
FIELD_LOWER_PRICE = 22
FIELD_VARIATION = 23
FIELD_VARIATION_PERCENTAGE = 24


DESCRIPTOR.enum_types_by_name['Field'] = _FIELD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


# @@protoc_insertion_point(module_scope)
