# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/corporate_actions/v1/dividends.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/corporate_actions/v1/dividends.proto',
  package='systemathics.apis.services.corporate_actions.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n?systemathics/apis/services/corporate_actions/v1/dividends.proto\x12/systemathics.apis.services.corporate_actions.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\x98\x01\n\x10\x44ividendsRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\"\\\n\x11\x44ividendsResponse\x12G\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x39.systemathics.apis.services.corporate_actions.v1.Dividend\"\x97\x01\n\x08\x44ividend\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12K\n\x04type\x18\x02 \x01(\x0e\x32=.systemathics.apis.services.corporate_actions.v1.DividendType\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x01\x12\r\n\x05score\x18\x04 \x01(\x01*4\n\x0c\x44ividendType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04\x43\x41SH\x10\x01\x12\t\n\x05STOCK\x10\x02\x32\xa7\x01\n\x10\x44ividendsService\x12\x92\x01\n\tDividends\x12\x41.systemathics.apis.services.corporate_actions.v1.DividendsRequest\x1a\x42.systemathics.apis.services.corporate_actions.v1.DividendsResponseb\x06proto3'
  ,
  dependencies=[google_dot_type_dot_date__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,])

_DIVIDENDTYPE = _descriptor.EnumDescriptor(
  name='DividendType',
  full_name='systemathics.apis.services.corporate_actions.v1.DividendType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CASH', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOCK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=646,
  serialized_end=698,
)
_sym_db.RegisterEnumDescriptor(_DIVIDENDTYPE)

DividendType = enum_type_wrapper.EnumTypeWrapper(_DIVIDENDTYPE)
UNSPECIFIED = 0
CASH = 1
STOCK = 2



_DIVIDENDSREQUEST = _descriptor.Descriptor(
  name='DividendsRequest',
  full_name='systemathics.apis.services.corporate_actions.v1.DividendsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.corporate_actions.v1.DividendsRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.corporate_actions.v1.DividendsRequest.constraints', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=244,
  serialized_end=396,
)


_DIVIDENDSRESPONSE = _descriptor.Descriptor(
  name='DividendsResponse',
  full_name='systemathics.apis.services.corporate_actions.v1.DividendsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='systemathics.apis.services.corporate_actions.v1.DividendsResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=398,
  serialized_end=490,
)


_DIVIDEND = _descriptor.Descriptor(
  name='Dividend',
  full_name='systemathics.apis.services.corporate_actions.v1.Dividend',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='systemathics.apis.services.corporate_actions.v1.Dividend.date', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='systemathics.apis.services.corporate_actions.v1.Dividend.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='systemathics.apis.services.corporate_actions.v1.Dividend.amount', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='systemathics.apis.services.corporate_actions.v1.Dividend.score', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=493,
  serialized_end=644,
)

_DIVIDENDSREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_DIVIDENDSREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_DIVIDENDSRESPONSE.fields_by_name['data'].message_type = _DIVIDEND
_DIVIDEND.fields_by_name['date'].message_type = google_dot_type_dot_date__pb2._DATE
_DIVIDEND.fields_by_name['type'].enum_type = _DIVIDENDTYPE
DESCRIPTOR.message_types_by_name['DividendsRequest'] = _DIVIDENDSREQUEST
DESCRIPTOR.message_types_by_name['DividendsResponse'] = _DIVIDENDSRESPONSE
DESCRIPTOR.message_types_by_name['Dividend'] = _DIVIDEND
DESCRIPTOR.enum_types_by_name['DividendType'] = _DIVIDENDTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DividendsRequest = _reflection.GeneratedProtocolMessageType('DividendsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DIVIDENDSREQUEST,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.dividends_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.DividendsRequest)
  })
_sym_db.RegisterMessage(DividendsRequest)

DividendsResponse = _reflection.GeneratedProtocolMessageType('DividendsResponse', (_message.Message,), {
  'DESCRIPTOR' : _DIVIDENDSRESPONSE,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.dividends_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.DividendsResponse)
  })
_sym_db.RegisterMessage(DividendsResponse)

Dividend = _reflection.GeneratedProtocolMessageType('Dividend', (_message.Message,), {
  'DESCRIPTOR' : _DIVIDEND,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.dividends_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.Dividend)
  })
_sym_db.RegisterMessage(Dividend)



_DIVIDENDSSERVICE = _descriptor.ServiceDescriptor(
  name='DividendsService',
  full_name='systemathics.apis.services.corporate_actions.v1.DividendsService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=701,
  serialized_end=868,
  methods=[
  _descriptor.MethodDescriptor(
    name='Dividends',
    full_name='systemathics.apis.services.corporate_actions.v1.DividendsService.Dividends',
    index=0,
    containing_service=None,
    input_type=_DIVIDENDSREQUEST,
    output_type=_DIVIDENDSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DIVIDENDSSERVICE)

DESCRIPTOR.services_by_name['DividendsService'] = _DIVIDENDSSERVICE

# @@protoc_insertion_point(module_scope)
